# colnade.expr

Expression AST nodes produced by column operations.

## Expr

::: colnade.expr.Expr
    options:
      members: false

## ColumnRef

::: colnade.expr.ColumnRef

## Literal

::: colnade.expr.Literal

## BinOp

::: colnade.expr.BinOp

## UnaryOp

::: colnade.expr.UnaryOp

## FunctionCall

::: colnade.expr.FunctionCall

## Agg

::: colnade.expr.Agg

## AliasedExpr

::: colnade.expr.AliasedExpr

## SortExpr

::: colnade.expr.SortExpr

## StructFieldAccess

::: colnade.expr.StructFieldAccess

## ListOp

::: colnade.expr.ListOp

## JoinCondition

::: colnade.expr.JoinCondition

## lit

::: colnade.expr.lit
